@@ -12,7 +12,10 @@ logger = logging.getLogger(__name__)
 
 
 def pytest_configure(config: Config) -> None:
-
+    config.addinivalue_line("markers", "maintainer(name): Email or nickname of test maintainer")
+    config.addinivalue_line("markers", "label(name, value): Test label")
+    config.addinivalue_line("markers", "artifact(path): Attach file to the test")
+    config.addinivalue_line("markers", "artifact_reference(name, value): Attach reference to the test")
     try:
         settings = load_settings()
         zebrunner_context.settings = settings
@@ -20,7 +23,8 @@ def pytest_configure(config: Config) -> None:
         field_errors = "\n".join([f"\033[93m {e['loc'][0]}\033[0m - {e['msg']}" for e in exc.errors()])
         warnings.warn(
             UserWarning(
-                "\033[1;31m Zebrunner plugin not configured properly because missing required config options.\n"
+                "\033[1;31m Zebrunner plugin not configured properly because missing required config options. "
+                "No results will be tracked in zebrunner.\n"
                 "Add it to environment variables or .env file.\n" + field_errors + "\n" * 3
             )
         )
@@ -28,12 +32,6 @@ def pytest_configure(config: Config) -> None:
 
     if settings.enabled:
         hooks = PytestHooks()
-
         config.pluginmanager.register(hooks)
         if config.pluginmanager.get_plugin("xdist") is not None:
             config.pluginmanager.register(XdistHooks())
-
-        config.addinivalue_line("markers", "maintainer(name): Email or nickname of test maintainer")
-        config.addinivalue_line("markers", "label(name, value): Test label")
-        config.addinivalue_line("markers", "artifact(path): Attach file to the test")
-        config.addinivalue_line("markers", "artifact_reference(name, value): Attach reference to the test")
