@@ -144,7 +144,7 @@ class ReportingService:
                 # https://docs.pytest.org/en/6.2.x/changelog.html?highlight=reprexceptioninfo#pytest-6-0-0rc1-2020-07-08
                 reason = report.longrepr
                 if isinstance(report.longrepr, ReprExceptionInfo) or isinstance(report.longrepr, ExceptionChainRepr):
-                    reason = report.longrepr.reprcrash.message + "\n\n" + reason
+                    reason = report.longrepr.reprcrash.message + "\n\n" + (str(reason) if reason else "")
 
             self.api.finish_test(
                 zebrunner_context.test_run_id,
@@ -166,8 +166,6 @@ class ReportingService:
                 zebrunner_handler: ZebrunnerHandler = handlers[0]  # type: ignore
                 zebrunner_handler.push_logs()
 
-        self.api.close()
-
     def start_test_session(
         self, session_id: str, capabilities: dict, desired_capabilities: dict, test_ids: List[int]
     ) -> Optional[str]:
@@ -185,7 +183,7 @@ class ReportingService:
             return zebrunner_session_id
         return None
 
-    def finish_test_session(self, zebrunner_session_id: str, related_tests: List[str]) -> None:
+    def finish_test_session(self, zebrunner_session_id: str, related_tests: List[int]) -> None:
         self.authorize()
         if zebrunner_context.test_run_is_active:
             self.api.finish_test_session(
